empathy r2237 - trunk/libempathy



Author: xclaesse
Date: Fri Jan 16 17:02:35 2009
New Revision: 2237
URL: http://svn.gnome.org/viewvc/empathy?rev=2237&view=rev

Log:
EmpathyDispatcher: Handle File channels that we didn't request.

Signed-off-by: Jonny Lamb <jonny lamb collabora co uk>

Modified:
   trunk/libempathy/empathy-dispatcher.c

Modified: trunk/libempathy/empathy-dispatcher.c
==============================================================================
--- trunk/libempathy/empathy-dispatcher.c	(original)
+++ trunk/libempathy/empathy-dispatcher.c	Fri Jan 16 17:02:35 2009
@@ -515,10 +515,11 @@
   if (g_hash_table_lookup (cd->outstanding_channels, object_path) != NULL)
     return;
 
-  /* Only pick up non-requested text channels. For all other it doesn't make
-   * sense to handle it if we didn't request it. The same goes for channels we
-   * discovered by the Channels property or ListChannels */
-  if (!incoming && tp_strdiff (channel_type, TP_IFACE_CHANNEL_TYPE_TEXT))
+  /* Only pick up non-requested text and file channels. For all other it
+   * doesn't make sense to handle it if we didn't request it. The same goes
+   * for channels we discovered by the Channels property or ListChannels */
+  if (!incoming && tp_strdiff (channel_type, TP_IFACE_CHANNEL_TYPE_TEXT)
+        && tp_strdiff (channel_type, EMP_IFACE_CHANNEL_TYPE_FILE_TRANSFER))
     {
       DEBUG ("Ignoring incoming channel of type %s on %s",
         channel_type, object_path);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]